@@ -11,7 +11,7 @@ types: dict[str, str] = {
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Scraper": "6d167939ca161a78",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "157873619ca0d0eb",
+    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "f05e81a8f1bcb307",
@@ -84,7 +84,7 @@ types: dict[str, str] = {
     "AWS::Athena::NamedQuery": "8adbac6f36c9aa6b",
     "AWS::Athena::PreparedStatement": "f136b10278378b55",
     "AWS::Athena::WorkGroup": "98125aa523006e5f",
-    "AWS::AutoScaling::AutoScalingGroup": "8fe2b009cdacf409",
+    "AWS::AutoScaling::AutoScalingGroup": "05a01deca7473008",
     "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
     "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
@@ -173,7 +173,7 @@ types: dict[str, str] = {
     "AWS::CodeDeploy::Application": "eea8100bd279b205",
     "AWS::CodeDeploy::DeploymentConfig": "394f39ae21382747",
     "AWS::CodeDeploy::DeploymentGroup": "36c8d71f30ed60e4",
-    "AWS::CodePipeline::CustomActionType": "ab3f9c5bbc8251df",
+    "AWS::CodePipeline::CustomActionType": "726ad61840645aa5",
     "AWS::CodePipeline::Pipeline": "580b88b2161ff941",
     "AWS::CodePipeline::Webhook": "a6ad2a4dc85ed032",
     "AWS::Cognito::IdentityPool": "3df22057c8e2ef54",
@@ -181,6 +181,7 @@ types: dict[str, str] = {
     "AWS::Cognito::IdentityPoolRoleAttachment": "2a5296f4ca5a2ff7",
     "AWS::Cognito::LogDeliveryConfiguration": "2e1fa665bc591a0b",
     "AWS::Cognito::ManagedLoginBranding": "5c891e6d32f0ba8d",
+    "AWS::Cognito::Terms": "f5bf1f3a97d979ba",
     "AWS::Cognito::UserPool": "4294848dd5d358d2",
     "AWS::Cognito::UserPoolClient": "56f070dbecb283f1",
     "AWS::Cognito::UserPoolDomain": "b89172fa4b1cf22a",
@@ -206,23 +207,23 @@ types: dict[str, str] = {
     "AWS::ControlTower::LandingZone": "96c88ada196eeb0e",
     "AWS::DLM::LifecyclePolicy": "0287ea6dffbb40a2",
     "AWS::DMS::DataMigration": "ade967581e1dfc34",
-    "AWS::DMS::DataProvider": "7c7365975be25275",
+    "AWS::DMS::DataProvider": "94c68c86840900fc",
     "AWS::DMS::InstanceProfile": "b289107706553b44",
     "AWS::DMS::MigrationProject": "b4b035d4b0f0b861",
     "AWS::DMS::ReplicationConfig": "563e9b573376b7ec",
     "AWS::DataPipeline::Pipeline": "f54867769cc566cf",
-    "AWS::DataSync::Agent": "733ace3e7eff9e68",
-    "AWS::DataSync::LocationAzureBlob": "02a252d30ebe9091",
-    "AWS::DataSync::LocationEFS": "dc695ceb626bd6aa",
-    "AWS::DataSync::LocationFSxLustre": "94324095d22e84c5",
-    "AWS::DataSync::LocationFSxONTAP": "fb2886550a94a821",
-    "AWS::DataSync::LocationFSxWindows": "7123c04a1159211f",
-    "AWS::DataSync::LocationHDFS": "9b0576d7bd1858ba",
-    "AWS::DataSync::LocationNFS": "bf12cdbf56d7c3b2",
-    "AWS::DataSync::LocationObjectStorage": "65e47a263206c90e",
-    "AWS::DataSync::LocationS3": "34db2462e6e07c08",
-    "AWS::DataSync::LocationSMB": "a045adab4853018c",
-    "AWS::DataSync::Task": "6a02fb3e9861f0e9",
+    "AWS::DataSync::Agent": "5f41806ea8ec42b9",
+    "AWS::DataSync::LocationAzureBlob": "d8a83e58123bc26d",
+    "AWS::DataSync::LocationEFS": "f74b4ff1503e9407",
+    "AWS::DataSync::LocationFSxLustre": "bf64014c70578e21",
+    "AWS::DataSync::LocationFSxONTAP": "f120a7ad0e329aaf",
+    "AWS::DataSync::LocationFSxWindows": "4fa3850617966c77",
+    "AWS::DataSync::LocationHDFS": "0639306ca013b8ec",
+    "AWS::DataSync::LocationNFS": "2659197742246dcd",
+    "AWS::DataSync::LocationObjectStorage": "a66b77a26a3e1747",
+    "AWS::DataSync::LocationS3": "0190e1a20831d5e0",
+    "AWS::DataSync::LocationSMB": "84f56a8c81ace8fd",
+    "AWS::DataSync::Task": "d896b335ffc11f10",
     "AWS::DirectoryService::MicrosoftAD": "380ff1d3d6a3a290",
     "AWS::DirectoryService::SimpleAD": "6d1dff201c211792",
     "AWS::DocDB::DBCluster": "be6f39b91c56eff9",
@@ -230,7 +231,8 @@ types: dict[str, str] = {
     "AWS::DocDB::DBInstance": "253562f270b587ac",
     "AWS::DocDB::DBSubnetGroup": "ccb97a9452b2284d",
     "AWS::DocDB::EventSubscription": "d22815028d03f301",
-    "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
+    "AWS::DocDB::GlobalCluster": "8a43a2ee7a595e9a",
+    "AWS::DynamoDB::GlobalTable": "bfb73ef91cc656d2",
     "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
     "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
     "AWS::EC2::CapacityReservationFleet": "3cec76abc326e6e7",
@@ -240,7 +242,7 @@ types: dict[str, str] = {
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "2667c807051620b3",
+    "AWS::EC2::EC2Fleet": "46456be2fbbfb010",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -249,7 +251,7 @@ types: dict[str, str] = {
     "AWS::EC2::Host": "09160fa1050b6c6f",
     "AWS::EC2::IPAM": "6fc9a0643e75121d",
     "AWS::EC2::IPAMAllocation": "c4cba824ca02ce4f",
-    "AWS::EC2::IPAMPool": "99dd938378f53c74",
+    "AWS::EC2::IPAMPool": "0509442cdc1e18b1",
     "AWS::EC2::IPAMPoolCidr": "873e7cc6e6afef96",
     "AWS::EC2::IPAMResourceDiscovery": "694c0afb626c30d8",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
@@ -285,7 +287,7 @@ types: dict[str, str] = {
     "AWS::EC2::SecurityGroupIngress": "367136b2f03f428c",
     "AWS::EC2::SecurityGroupVpcAssociation": "f48680388ee894fe",
     "AWS::EC2::SnapshotBlockPublicAccess": "f6434397a8c7e382",
-    "AWS::EC2::SpotFleet": "d389b8af6ecb0e0b",
+    "AWS::EC2::SpotFleet": "b3c6b5b2f4a5b7d2",
     "AWS::EC2::Subnet": "a60b8dc0c7f50396",
     "AWS::EC2::SubnetCidrBlock": "473785ce782ba18f",
     "AWS::EC2::SubnetNetworkAclAssociation": "6b4f4042734e67b7",
@@ -323,7 +325,7 @@ types: dict[str, str] = {
     "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
     "AWS::EC2::VPCPeeringConnection": "e01a466d269170ed",
     "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
-    "AWS::EC2::VPNConnection": "0f47659c40e916e6",
+    "AWS::EC2::VPNConnection": "96656bab170e1c0b",
     "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
     "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
@@ -336,10 +338,10 @@ types: dict[str, str] = {
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
     "AWS::ECR::Repository": "d569f41026af3be8",
     "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
-    "AWS::ECS::CapacityProvider": "5804cc1956f638f2",
+    "AWS::ECS::CapacityProvider": "e838474b874da177",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
-    "AWS::ECS::ExpressGatewayService": "5d3c22b7a1c19b87",
+    "AWS::ECS::ExpressGatewayService": "a04769bd1a468834",
     "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
     "AWS::ECS::Service": "585001d48158728c",
     "AWS::ECS::TaskDefinition": "ac3c5ff140cb5d7d",
@@ -353,13 +355,13 @@ types: dict[str, str] = {
     "AWS::EKS::Cluster": "f17916cc287d09df",
     "AWS::EKS::FargateProfile": "71e821ce6e609193",
     "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
-    "AWS::EKS::Nodegroup": "287f4d78035a9e03",
+    "AWS::EKS::Nodegroup": "4b7b3ba6fffc3e8a",
     "AWS::EKS::PodIdentityAssociation": "d4249aaeb9409683",
     "AWS::EMR::Cluster": "ac0466c8197ef416",
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
     "AWS::EMR::InstanceGroupConfig": "57ea4fa9b7b6f658",
     "AWS::EMR::SecurityConfiguration": "59f2b8145f1762e6",
-    "AWS::EMR::Step": "816de91a3e21c0a7",
+    "AWS::EMR::Step": "87ecffcedd5d780a",
     "AWS::EMR::WALWorkspace": "1acf5569fff4fcbe",
     "AWS::EMRContainers::VirtualCluster": "d56c1799bc259539",
     "AWS::EMRServerless::Application": "b8f0bd50831c9f1e",
@@ -455,7 +457,7 @@ types: dict[str, str] = {
     "AWS::ImageBuilder::Component": "c686558ba853a496",
     "AWS::ImageBuilder::ContainerRecipe": "882a5a874ec51f81",
     "AWS::ImageBuilder::DistributionConfiguration": "7b34e1b0b9958d96",
-    "AWS::ImageBuilder::Image": "c690c6fdfc55f601",
+    "AWS::ImageBuilder::Image": "7eaad9cf0d30061e",
     "AWS::ImageBuilder::ImagePipeline": "8ea2eca13ceb1fc8",
     "AWS::ImageBuilder::ImageRecipe": "83c0121011689366",
     "AWS::ImageBuilder::InfrastructureConfiguration": "703bdd9fb961cbcd",
@@ -473,7 +475,7 @@ types: dict[str, str] = {
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
     "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
-    "AWS::KafkaConnect::Connector": "08b81c973eb812dd",
+    "AWS::KafkaConnect::Connector": "9ca5dec677704b80",
     "AWS::KafkaConnect::CustomPlugin": "f04fc57818e8ddb4",
     "AWS::KafkaConnect::WorkerConfiguration": "8a9b885926e8a00c",
     "AWS::Kinesis::ResourcePolicy": "39996915810e234a",
@@ -503,7 +505,7 @@ types: dict[str, str] = {
     "AWS::Logs::DeliverySource": "67b64320b397d6cd",
     "AWS::Logs::Destination": "ff1e6b020f2cf8e7",
     "AWS::Logs::LogAnomalyDetector": "e2ee984f7c775ef5",
-    "AWS::Logs::LogGroup": "7144d581f2e97160",
+    "AWS::Logs::LogGroup": "364a0898ae2cfeb8",
     "AWS::Logs::LogStream": "bb97d1fb38ff99db",
     "AWS::Logs::MetricFilter": "9a1d875b35cd0f81",
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
@@ -535,12 +537,12 @@ types: dict[str, str] = {
     "AWS::MediaPackageV2::Channel": "62a1a362e9e8f627",
     "AWS::MediaPackageV2::ChannelGroup": "2aa9c5f3fad67e76",
     "AWS::MediaPackageV2::ChannelPolicy": "e79aba75cf23e354",
-    "AWS::MediaPackageV2::OriginEndpoint": "14921a18e39abb19",
+    "AWS::MediaPackageV2::OriginEndpoint": "ebe0f0a5cdb97975",
     "AWS::MediaPackageV2::OriginEndpointPolicy": "8cd12a52dceffffe",
     "AWS::MediaTailor::Channel": "fe2dcc2566975851",
     "AWS::MediaTailor::ChannelPolicy": "1c9cf783f5b18afb",
     "AWS::MediaTailor::LiveSource": "a884632fe226b938",
-    "AWS::MediaTailor::PlaybackConfiguration": "190be0c2c7795486",
+    "AWS::MediaTailor::PlaybackConfiguration": "45549228850e8811",
     "AWS::MediaTailor::SourceLocation": "7ddd02a26d6de0a4",
     "AWS::MediaTailor::VodSource": "746fa4c2fdf8d70a",
     "AWS::NetworkFirewall::Firewall": "e72dd64edb0563ec",
@@ -595,16 +597,18 @@ types: dict[str, str] = {
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry": "756784fc38981208",
     "AWS::PCAConnectorSCEP::Challenge": "66f2129c2055583e",
     "AWS::PCAConnectorSCEP::Connector": "9cbd2b6a05e6eb0d",
+    "AWS::PaymentCryptography::Alias": "04360ee15415de2d",
+    "AWS::PaymentCryptography::Key": "af26a71fe21eb480",
     "AWS::Pipes::Pipe": "052457cd8332df71",
     "AWS::RAM::Permission": "740a6e8ada63a5a3",
     "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
     "AWS::RDS::DBCluster": "9c7540d3d4699497",
     "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
-    "AWS::RDS::DBInstance": "b7cc196bc1fe0b0d",
+    "AWS::RDS::DBInstance": "25726c9e8467f4c5",
     "AWS::RDS::DBParameterGroup": "d29cf38b861f6048",
-    "AWS::RDS::DBProxy": "6a3bd3de0c3a9c96",
-    "AWS::RDS::DBProxyEndpoint": "db0fcba23f51c12d",
-    "AWS::RDS::DBProxyTargetGroup": "8ee69ccb4de53286",
+    "AWS::RDS::DBProxy": "308e70305b33a892",
+    "AWS::RDS::DBProxyEndpoint": "17943cc672d084c2",
+    "AWS::RDS::DBProxyTargetGroup": "b584b6fb42fcd4c7",
     "AWS::RDS::DBSecurityGroup": "42f555e782cd9946",
     "AWS::RDS::DBSecurityGroupIngress": "1a14ad6e73c0b6b7",
     "AWS::RDS::DBShardGroup": "df6b36c7e099595a",
@@ -643,7 +647,7 @@ types: dict[str, str] = {
     "AWS::Route53::KeySigningKey": "a9a67ae6c371fcf4",
     "AWS::Route53::RecordSet": "c01e9eccec2e3b83",
     "AWS::Route53::RecordSetGroup": "8300e7c48d942273",
-    "AWS::Route53Profiles::Profile": "cf36999836466e94",
+    "AWS::Route53Profiles::Profile": "cb0a28f9bebd044e",
     "AWS::Route53Profiles::ProfileAssociation": "fa568e44f7d9e9f2",
     "AWS::Route53Profiles::ProfileResourceAssociation": "73d6b9da50afa75b",
     "AWS::Route53Resolver::FirewallDomainList": "76957613d7f85b1b",
@@ -672,7 +676,7 @@ types: dict[str, str] = {
     "AWS::S3Tables::TableBucketPolicy": "b3ab0f647d7aed60",
     "AWS::S3Tables::TablePolicy": "0ed301e1967bd6a0",
     "AWS::SDB::Domain": "48c38397df169b43",
-    "AWS::SES::ConfigurationSet": "77b6745a5f444407",
+    "AWS::SES::ConfigurationSet": "97470ae3c0d408ae",
     "AWS::SES::ConfigurationSetEventDestination": "f4e74b1d7e859c34",
     "AWS::SES::ContactList": "c5a40d0f3d530e19",
     "AWS::SES::DedicatedIpPool": "1485a5989d771f62",
@@ -728,7 +732,7 @@ types: dict[str, str] = {
     "AWS::SecretsManager::SecretTargetAttachment": "3bf4404734c82308",
     "AWS::SecurityHub::AutomationRule": "f6c9ad12353e867b",
     "AWS::SecurityHub::AutomationRuleV2": "382b90fb3949f096",
-    "AWS::SecurityHub::ConnectorV2": "11285780497e0a3f",
+    "AWS::SecurityHub::ConnectorV2": "b4e780d54c354d65",
     "AWS::SecurityHub::DelegatedAdmin": "a328fc62a9f2f7e2",
     "AWS::SecurityHub::Hub": "9f6cb2d8967bfcf6",
     "AWS::SecurityHub::HubV2": "b1544234a77fc9a5",
