@@ -160,8 +160,8 @@ types: dict[str, str] = {
     "AWS::Bedrock::PromptVersion": "41e3e79078ba156a",
     "AWS::BedrockAgentCore::BrowserCustom": "b3f585b2b83595e9",
     "AWS::BedrockAgentCore::CodeInterpreterCustom": "a4789ce5aa400e99",
-    "AWS::BedrockAgentCore::Gateway": "247c1db4e4082ec0",
-    "AWS::BedrockAgentCore::GatewayTarget": "2214118622bce5a2",
+    "AWS::BedrockAgentCore::Gateway": "a629441d622699ce",
+    "AWS::BedrockAgentCore::GatewayTarget": "f190da008ea2a70a",
     "AWS::BedrockAgentCore::Memory": "87837077e3884e10",
     "AWS::BedrockAgentCore::Runtime": "691d685a9f3413ad",
     "AWS::BedrockAgentCore::RuntimeEndpoint": "624b26411473f25c",
@@ -219,11 +219,11 @@ types: dict[str, str] = {
     "AWS::CloudFront::ConnectionFunction": "d78bd117dcdb2119",
     "AWS::CloudFront::ConnectionGroup": "68ca2c6e67355a40",
     "AWS::CloudFront::ContinuousDeploymentPolicy": "bf0fd1f8e692b34d",
-    "AWS::CloudFront::Distribution": "23e0328c26fb5ba6",
+    "AWS::CloudFront::Distribution": "fab747f0e73ef952",
     "AWS::CloudFront::DistributionTenant": "0645b8023b061e15",
     "AWS::CloudFront::Function": "f3bfd8485e232a78",
     "AWS::CloudFront::KeyGroup": "7a9f609d809f1f8e",
-    "AWS::CloudFront::KeyValueStore": "674d07fa20c06be2",
+    "AWS::CloudFront::KeyValueStore": "59c36f41cb955ac8",
     "AWS::CloudFront::MonitoringSubscription": "f9dae15a96e422a7",
     "AWS::CloudFront::OriginAccessControl": "17f386694e5709fe",
     "AWS::CloudFront::OriginRequestPolicy": "97711158d1bc4353",
@@ -369,13 +369,13 @@ types: dict[str, str] = {
     "AWS::DataSync::LocationS3": "0190e1a20831d5e0",
     "AWS::DataSync::LocationSMB": "84f56a8c81ace8fd",
     "AWS::DataSync::Task": "d896b335ffc11f10",
-    "AWS::DataZone::Connection": "c4ca9e4d789a7534",
-    "AWS::DataZone::DataSource": "45679439037c4108",
-    "AWS::DataZone::Domain": "4612d1fe73774fe0",
+    "AWS::DataZone::Connection": "36206200921236e5",
+    "AWS::DataZone::DataSource": "5522a6a5cd1e1a3e",
+    "AWS::DataZone::Domain": "a73fade42476d81b",
     "AWS::DataZone::DomainUnit": "711f0c6aabf717bd",
     "AWS::DataZone::Environment": "90d9cbf3a3ed746b",
     "AWS::DataZone::EnvironmentActions": "74f98b0cb8b35451",
-    "AWS::DataZone::EnvironmentBlueprintConfiguration": "3aeda3b79f4458c1",
+    "AWS::DataZone::EnvironmentBlueprintConfiguration": "2eaef7d5eed54c20",
     "AWS::DataZone::EnvironmentProfile": "e0cb32e5d86cbc08",
     "AWS::DataZone::FormType": "c4cdf1e5e0a284ed",
     "AWS::DataZone::GroupProfile": "74ae2ae09d16d68e",
@@ -383,8 +383,8 @@ types: dict[str, str] = {
     "AWS::DataZone::PolicyGrant": "4a122be9c506c908",
     "AWS::DataZone::Project": "2f7d1fc808f3eed8",
     "AWS::DataZone::ProjectMembership": "9afaeb6b2c0a7ad8",
-    "AWS::DataZone::ProjectProfile": "fb23ccf55c4c1ec7",
-    "AWS::DataZone::SubscriptionTarget": "b9b0c7c5b0d7c587",
+    "AWS::DataZone::ProjectProfile": "069e12fef6b972f5",
+    "AWS::DataZone::SubscriptionTarget": "ed731ffbd196f802",
     "AWS::DataZone::UserProfile": "db3a5863b7d055bd",
     "AWS::Deadline::Farm": "c9bbcca2240de1e6",
     "AWS::Deadline::Fleet": "b90dfd2bd6566e09",
@@ -410,8 +410,9 @@ types: dict[str, str] = {
     "AWS::DocDB::DBInstance": "253562f270b587ac",
     "AWS::DocDB::DBSubnetGroup": "ccb97a9452b2284d",
     "AWS::DocDB::EventSubscription": "d22815028d03f301",
+    "AWS::DocDB::GlobalCluster": "8a43a2ee7a595e9a",
     "AWS::DocDBElastic::Cluster": "5686e00f54e9aae6",
-    "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
+    "AWS::DynamoDB::GlobalTable": "bfb73ef91cc656d2",
     "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
     "AWS::EC2::CapacityManagerDataExport": "eadbbd5d7fd8fd3c",
     "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
@@ -432,7 +433,7 @@ types: dict[str, str] = {
     "AWS::EC2::Host": "ba21ffd03e701456",
     "AWS::EC2::IPAM": "6fc9a0643e75121d",
     "AWS::EC2::IPAMAllocation": "c4cba824ca02ce4f",
-    "AWS::EC2::IPAMPool": "99dd938378f53c74",
+    "AWS::EC2::IPAMPool": "0509442cdc1e18b1",
     "AWS::EC2::IPAMPoolCidr": "873e7cc6e6afef96",
     "AWS::EC2::IPAMResourceDiscovery": "694c0afb626c30d8",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
@@ -530,7 +531,7 @@ types: dict[str, str] = {
     "AWS::ECR::Repository": "d569f41026af3be8",
     "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
     "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
-    "AWS::ECS::CapacityProvider": "683155ff5bdccc42",
+    "AWS::ECS::CapacityProvider": "e838474b874da177",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "a04769bd1a468834",
@@ -547,7 +548,7 @@ types: dict[str, str] = {
     "AWS::EKS::Cluster": "f17916cc287d09df",
     "AWS::EKS::FargateProfile": "71e821ce6e609193",
     "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
-    "AWS::EKS::Nodegroup": "287f4d78035a9e03",
+    "AWS::EKS::Nodegroup": "4b7b3ba6fffc3e8a",
     "AWS::EKS::PodIdentityAssociation": "d4249aaeb9409683",
     "AWS::EMR::Cluster": "ac0466c8197ef416",
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
@@ -626,13 +627,13 @@ types: dict[str, str] = {
     "AWS::FraudDetector::Variable": "2e6f2ffc6a3c7b4c",
     "AWS::GameLift::Alias": "5c014b121a693be2",
     "AWS::GameLift::Build": "b9b218f4180db0c3",
-    "AWS::GameLift::Fleet": "7b1de719fe632688",
+    "AWS::GameLift::Fleet": "08322d2081d018bb",
     "AWS::GameLift::GameServerGroup": "5cc95b605dfa9939",
     "AWS::GameLift::GameSessionQueue": "aba577170457cc78",
     "AWS::GameLift::Location": "74151dc88b4069da",
     "AWS::GameLift::MatchmakingConfiguration": "b3a52351df7bf443",
     "AWS::GameLift::MatchmakingRuleSet": "8e5d97e0ee9acaa8",
-    "AWS::GameLift::Script": "d2777b50e200b1a3",
+    "AWS::GameLift::Script": "4571db51b8dc638d",
     "AWS::GammaDilithium::JobDefinition": "bda58ee4c07eaf24",
     "AWS::GlobalAccelerator::Accelerator": "8c74434fcd81b4e7",
     "AWS::GlobalAccelerator::CrossAccountAttachment": "8c37543e6efb0b27",
@@ -776,7 +777,7 @@ types: dict[str, str] = {
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
     "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
-    "AWS::KafkaConnect::Connector": "08b81c973eb812dd",
+    "AWS::KafkaConnect::Connector": "9ca5dec677704b80",
     "AWS::KafkaConnect::CustomPlugin": "f04fc57818e8ddb4",
     "AWS::KafkaConnect::WorkerConfiguration": "8a9b885926e8a00c",
     "AWS::Kendra::DataSource": "46ba2f6e9c75d715",
@@ -847,7 +848,7 @@ types: dict[str, str] = {
     "AWS::Logs::Destination": "ff1e6b020f2cf8e7",
     "AWS::Logs::Integration": "0bc4c86432380358",
     "AWS::Logs::LogAnomalyDetector": "e2ee984f7c775ef5",
-    "AWS::Logs::LogGroup": "7144d581f2e97160",
+    "AWS::Logs::LogGroup": "364a0898ae2cfeb8",
     "AWS::Logs::LogStream": "bb97d1fb38ff99db",
     "AWS::Logs::MetricFilter": "9a1d875b35cd0f81",
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
@@ -865,6 +866,7 @@ types: dict[str, str] = {
     "AWS::MSK::ServerlessCluster": "9eb8b6f85a407e2e",
     "AWS::MSK::VpcConnection": "6aeb07916b90c80a",
     "AWS::MWAA::Environment": "c28ab3624f1d638c",
+    "AWS::MWAAServerless::Workflow": "5281a04e576dc1cc",
     "AWS::Macie::AllowList": "40bd0a0377639bda",
     "AWS::Macie::CustomDataIdentifier": "c0c5ba901caafe31",
     "AWS::Macie::FindingsFilter": "d3c6be2a3d872987",
@@ -909,7 +911,7 @@ types: dict[str, str] = {
     "AWS::MediaPackageV2::Channel": "62a1a362e9e8f627",
     "AWS::MediaPackageV2::ChannelGroup": "2aa9c5f3fad67e76",
     "AWS::MediaPackageV2::ChannelPolicy": "e79aba75cf23e354",
-    "AWS::MediaPackageV2::OriginEndpoint": "14921a18e39abb19",
+    "AWS::MediaPackageV2::OriginEndpoint": "ebe0f0a5cdb97975",
     "AWS::MediaPackageV2::OriginEndpointPolicy": "8cd12a52dceffffe",
     "AWS::MediaTailor::Channel": "fe2dcc2566975851",
     "AWS::MediaTailor::ChannelPolicy": "1c9cf783f5b18afb",
@@ -1035,10 +1037,10 @@ types: dict[str, str] = {
     "AWS::QLDB::Ledger": "eb38fe7089c60665",
     "AWS::QLDB::Stream": "09aa8fbe0fae7277",
     "AWS::QuickSight::Analysis": "9ed141915b114fbd",
-    "AWS::QuickSight::CustomPermissions": "ac2895cdbe3ee0f3",
+    "AWS::QuickSight::CustomPermissions": "da6da182c0c23fb4",
     "AWS::QuickSight::Dashboard": "b1b7368590994f86",
     "AWS::QuickSight::DataSet": "0e9e94a2fd9e8f95",
-    "AWS::QuickSight::DataSource": "2c06940063cc0519",
+    "AWS::QuickSight::DataSource": "407708b753626383",
     "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
     "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
     "AWS::QuickSight::Template": "9f99a52291094b16",
@@ -1047,14 +1049,14 @@ types: dict[str, str] = {
     "AWS::QuickSight::VPCConnection": "96804832324c84da",
     "AWS::RAM::Permission": "740a6e8ada63a5a3",
     "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
-    "AWS::RDS::CustomDBEngineVersion": "e9699c76b9971105",
+    "AWS::RDS::CustomDBEngineVersion": "67b3a7d6ee10021d",
     "AWS::RDS::DBCluster": "9c7540d3d4699497",
     "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
-    "AWS::RDS::DBInstance": "b7cc196bc1fe0b0d",
+    "AWS::RDS::DBInstance": "25726c9e8467f4c5",
     "AWS::RDS::DBParameterGroup": "d29cf38b861f6048",
-    "AWS::RDS::DBProxy": "6a3bd3de0c3a9c96",
-    "AWS::RDS::DBProxyEndpoint": "db0fcba23f51c12d",
-    "AWS::RDS::DBProxyTargetGroup": "8ee69ccb4de53286",
+    "AWS::RDS::DBProxy": "308e70305b33a892",
+    "AWS::RDS::DBProxyEndpoint": "17943cc672d084c2",
+    "AWS::RDS::DBProxyTargetGroup": "b584b6fb42fcd4c7",
     "AWS::RDS::DBSecurityGroup": "42f555e782cd9946",
     "AWS::RDS::DBSecurityGroupIngress": "1a14ad6e73c0b6b7",
     "AWS::RDS::DBShardGroup": "df6b36c7e099595a",
@@ -1063,7 +1065,7 @@ types: dict[str, str] = {
     "AWS::RDS::GlobalCluster": "a87d030f06c19d47",
     "AWS::RDS::Integration": "f7415a6a9c4a11da",
     "AWS::RDS::OptionGroup": "d89f528bd7bdd696",
-    "AWS::RTBFabric::InboundExternalLink": "98ec1c2b72a83612",
+    "AWS::RTBFabric::InboundExternalLink": "c3c8cf2492a32672",
     "AWS::RTBFabric::Link": "dc636a54e270d058",
     "AWS::RTBFabric::OutboundExternalLink": "add07845ef354c07",
     "AWS::RTBFabric::RequesterGateway": "80b4de97c259ecb8",
@@ -1148,7 +1150,7 @@ types: dict[str, str] = {
     "AWS::S3Vectors::VectorBucket": "eae6d86b8ee33282",
     "AWS::S3Vectors::VectorBucketPolicy": "ecd7e75e3e0d291d",
     "AWS::SDB::Domain": "48c38397df169b43",
-    "AWS::SES::ConfigurationSet": "77b6745a5f444407",
+    "AWS::SES::ConfigurationSet": "97470ae3c0d408ae",
     "AWS::SES::ConfigurationSetEventDestination": "f4e74b1d7e859c34",
     "AWS::SES::ContactList": "c5a40d0f3d530e19",
     "AWS::SES::DedicatedIpPool": "1485a5989d771f62",
@@ -1357,7 +1359,7 @@ types: dict[str, str] = {
     "AWS::WAFv2::RuleGroup": "b1d084941142148b",
     "AWS::WAFv2::WebACL": "892990086386d387",
     "AWS::WAFv2::WebACLAssociation": "d0181fa0b0d2faac",
-    "AWS::Wisdom::AIAgent": "a27424c39bbaeffd",
+    "AWS::Wisdom::AIAgent": "5ee8ab1c7c6da31a",
     "AWS::Wisdom::AIAgentVersion": "ebc006eddb995353",
     "AWS::Wisdom::AIGuardrail": "b55d708e74222e39",
     "AWS::Wisdom::AIGuardrailVersion": "18170fb3d4df70e6",
