@@ -6,7 +6,7 @@ types: dict[str, str] = {
     "AWS::ACMPCA::CertificateAuthority": "97b6ba94b51843fc",
     "AWS::ACMPCA::CertificateAuthorityActivation": "a62fb980b49a2961",
     "AWS::ACMPCA::Permission": "f334231645d9b9b9",
-    "AWS::ARCRegionSwitch::Plan": "fdbe98851347ecff",
+    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "f05e81a8f1bcb307",
@@ -46,7 +46,7 @@ types: dict[str, str] = {
     "AWS::Athena::NamedQuery": "8adbac6f36c9aa6b",
     "AWS::Athena::PreparedStatement": "f136b10278378b55",
     "AWS::Athena::WorkGroup": "98125aa523006e5f",
-    "AWS::AutoScaling::AutoScalingGroup": "1176577a6acfd8f9",
+    "AWS::AutoScaling::AutoScalingGroup": "05a01deca7473008",
     "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
     "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
@@ -75,7 +75,7 @@ types: dict[str, str] = {
     "AWS::CloudFormation::Macro": "8517053591f9eceb",
     "AWS::CloudFormation::ResourceDefaultVersion": "f614137749ff39d3",
     "AWS::CloudFormation::ResourceVersion": "cb8c2d939b790590",
-    "AWS::CloudFormation::Stack": "1941e510fbdc7265",
+    "AWS::CloudFormation::Stack": "089169583d0e826d",
     "AWS::CloudFormation::StackSet": "bf26be80cf86dbfd",
     "AWS::CloudFormation::WaitCondition": "6c5dfc2296cd28df",
     "AWS::CloudFormation::WaitConditionHandle": "edba290fd70976a3",
@@ -123,27 +123,28 @@ types: dict[str, str] = {
     "AWS::ControlTower::EnabledControl": "ac0e492fde8853d9",
     "AWS::ControlTower::LandingZone": "96c88ada196eeb0e",
     "AWS::DLM::LifecyclePolicy": "0287ea6dffbb40a2",
-    "AWS::DMS::DataProvider": "7c7365975be25275",
+    "AWS::DMS::DataProvider": "94c68c86840900fc",
     "AWS::DMS::InstanceProfile": "b289107706553b44",
     "AWS::DMS::MigrationProject": "b4b035d4b0f0b861",
     "AWS::DataPipeline::Pipeline": "f54867769cc566cf",
-    "AWS::DataSync::Agent": "733ace3e7eff9e68",
-    "AWS::DataSync::LocationAzureBlob": "02a252d30ebe9091",
-    "AWS::DataSync::LocationHDFS": "9b0576d7bd1858ba",
-    "AWS::DataSync::LocationNFS": "bf12cdbf56d7c3b2",
-    "AWS::DataSync::LocationObjectStorage": "65e47a263206c90e",
-    "AWS::DataSync::LocationS3": "34db2462e6e07c08",
-    "AWS::DataSync::LocationSMB": "a045adab4853018c",
-    "AWS::DataSync::Task": "6a02fb3e9861f0e9",
+    "AWS::DataSync::Agent": "5f41806ea8ec42b9",
+    "AWS::DataSync::LocationAzureBlob": "d8a83e58123bc26d",
+    "AWS::DataSync::LocationEFS": "f74b4ff1503e9407",
+    "AWS::DataSync::LocationHDFS": "0639306ca013b8ec",
+    "AWS::DataSync::LocationNFS": "2659197742246dcd",
+    "AWS::DataSync::LocationObjectStorage": "a66b77a26a3e1747",
+    "AWS::DataSync::LocationS3": "0190e1a20831d5e0",
+    "AWS::DataSync::LocationSMB": "84f56a8c81ace8fd",
+    "AWS::DataSync::Task": "d896b335ffc11f10",
     "AWS::DirectoryService::MicrosoftAD": "380ff1d3d6a3a290",
     "AWS::DirectoryService::SimpleAD": "6d1dff201c211792",
-    "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
+    "AWS::DynamoDB::GlobalTable": "bfb73ef91cc656d2",
     "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
-    "AWS::EC2::CapacityReservation": "5b0dc1ffda2169f7",
+    "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
     "AWS::EC2::CapacityReservationFleet": "3cec76abc326e6e7",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "fb40b2f2f1d3a93a",
+    "AWS::EC2::EC2Fleet": "46456be2fbbfb010",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -152,12 +153,12 @@ types: dict[str, str] = {
     "AWS::EC2::Host": "09160fa1050b6c6f",
     "AWS::EC2::IPAM": "6fc9a0643e75121d",
     "AWS::EC2::IPAMAllocation": "c4cba824ca02ce4f",
-    "AWS::EC2::IPAMPool": "99dd938378f53c74",
+    "AWS::EC2::IPAMPool": "0509442cdc1e18b1",
     "AWS::EC2::IPAMPoolCidr": "873e7cc6e6afef96",
     "AWS::EC2::IPAMResourceDiscovery": "694c0afb626c30d8",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "f1341090e0e57749",
-    "AWS::EC2::Instance": "51763c48d327df98",
+    "AWS::EC2::Instance": "a922ff4a1cb10687",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::KeyPair": "349deb28f79434e4",
     "AWS::EC2::LaunchTemplate": "2da58e06d7524dc5",
@@ -174,12 +175,17 @@ types: dict[str, str] = {
     "AWS::EC2::PlacementGroup": "8dca9ce7eb8b50ac",
     "AWS::EC2::PrefixList": "c53292c8686d14de",
     "AWS::EC2::Route": "0ff811157612151a",
+    "AWS::EC2::RouteServer": "f53338d8b3c6499a",
+    "AWS::EC2::RouteServerAssociation": "22bb952c9a61f2a9",
+    "AWS::EC2::RouteServerEndpoint": "40a2b7461aa985fa",
+    "AWS::EC2::RouteServerPeer": "0b52f45b8ea8cbac",
+    "AWS::EC2::RouteServerPropagation": "0dd3a42d71c85b11",
     "AWS::EC2::RouteTable": "67bdbfcad069c66a",
     "AWS::EC2::SecurityGroup": "5390282384be7866",
     "AWS::EC2::SecurityGroupEgress": "840df778de9b4be2",
     "AWS::EC2::SecurityGroupIngress": "367136b2f03f428c",
     "AWS::EC2::SecurityGroupVpcAssociation": "f48680388ee894fe",
-    "AWS::EC2::SpotFleet": "8aa7c37da362d035",
+    "AWS::EC2::SpotFleet": "b3c6b5b2f4a5b7d2",
     "AWS::EC2::Subnet": "a60b8dc0c7f50396",
     "AWS::EC2::SubnetCidrBlock": "473785ce782ba18f",
     "AWS::EC2::SubnetNetworkAclAssociation": "6b4f4042734e67b7",
@@ -216,7 +222,7 @@ types: dict[str, str] = {
     "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
     "AWS::EC2::VPCPeeringConnection": "e01a466d269170ed",
     "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
-    "AWS::EC2::VPNConnection": "0f47659c40e916e6",
+    "AWS::EC2::VPNConnection": "96656bab170e1c0b",
     "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
     "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
@@ -228,13 +234,13 @@ types: dict[str, str] = {
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
     "AWS::ECR::Repository": "d569f41026af3be8",
-    "AWS::ECR::RepositoryCreationTemplate": "260745c34d057c07",
-    "AWS::ECS::CapacityProvider": "5804cc1956f638f2",
+    "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
+    "AWS::ECS::CapacityProvider": "e838474b874da177",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "5d3c22b7a1c19b87",
     "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
-    "AWS::ECS::Service": "75313434fba04f66",
+    "AWS::ECS::Service": "585001d48158728c",
     "AWS::ECS::TaskDefinition": "ac3c5ff140cb5d7d",
     "AWS::ECS::TaskSet": "93284b06523a426d",
     "AWS::EFS::AccessPoint": "2f62161de474e688",
@@ -245,13 +251,13 @@ types: dict[str, str] = {
     "AWS::EKS::Capability": "7816d4a96b146b20",
     "AWS::EKS::Cluster": "f17916cc287d09df",
     "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
-    "AWS::EKS::Nodegroup": "287f4d78035a9e03",
+    "AWS::EKS::Nodegroup": "4b7b3ba6fffc3e8a",
     "AWS::EKS::PodIdentityAssociation": "d4249aaeb9409683",
     "AWS::EMR::Cluster": "ac0466c8197ef416",
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
     "AWS::EMR::InstanceGroupConfig": "57ea4fa9b7b6f658",
     "AWS::EMR::SecurityConfiguration": "59f2b8145f1762e6",
-    "AWS::EMR::Step": "816de91a3e21c0a7",
+    "AWS::EMR::Step": "87ecffcedd5d780a",
     "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
     "AWS::ElastiCache::ParameterGroup": "b0e1dec3cd05f739",
     "AWS::ElastiCache::ReplicationGroup": "59defd83ba1cb2f2",
@@ -271,6 +277,8 @@ types: dict[str, str] = {
     "AWS::ElasticLoadBalancingV2::ListenerRule": "813e329d3a1f8231",
     "AWS::ElasticLoadBalancingV2::LoadBalancer": "f4f22fe5256925cc",
     "AWS::ElasticLoadBalancingV2::TargetGroup": "f7dbf6903e0a1263",
+    "AWS::ElasticLoadBalancingV2::TrustStore": "7300a052ca504e65",
+    "AWS::ElasticLoadBalancingV2::TrustStoreRevocation": "593a78e5ca9c2be3",
     "AWS::Elasticsearch::Domain": "c6414ef13f2fedbe",
     "AWS::Events::EventBus": "87abb79a2ea2a571",
     "AWS::Events::EventBusPolicy": "7cb0a2b18483bb52",
@@ -320,7 +328,7 @@ types: dict[str, str] = {
     "AWS::ImageBuilder::Component": "c686558ba853a496",
     "AWS::ImageBuilder::ContainerRecipe": "882a5a874ec51f81",
     "AWS::ImageBuilder::DistributionConfiguration": "7b34e1b0b9958d96",
-    "AWS::ImageBuilder::Image": "c690c6fdfc55f601",
+    "AWS::ImageBuilder::Image": "7eaad9cf0d30061e",
     "AWS::ImageBuilder::ImagePipeline": "8ea2eca13ceb1fc8",
     "AWS::ImageBuilder::ImageRecipe": "83c0121011689366",
     "AWS::ImageBuilder::InfrastructureConfiguration": "703bdd9fb961cbcd",
@@ -335,11 +343,21 @@ types: dict[str, str] = {
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
     "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
+    "AWS::KafkaConnect::Connector": "9ca5dec677704b80",
+    "AWS::KafkaConnect::CustomPlugin": "f04fc57818e8ddb4",
+    "AWS::KafkaConnect::WorkerConfiguration": "8a9b885926e8a00c",
     "AWS::Kinesis::ResourcePolicy": "39996915810e234a",
     "AWS::Kinesis::Stream": "e6126822cd48b2b0",
     "AWS::Kinesis::StreamConsumer": "7ce125c877a406e0",
     "AWS::KinesisAnalyticsV2::Application": "0c3ba846a178e940",
     "AWS::KinesisFirehose::DeliveryStream": "6e5b365496a735c9",
+    "AWS::LakeFormation::DataCellsFilter": "6ac217ac96918929",
+    "AWS::LakeFormation::DataLakeSettings": "d9b68c11de60cdd0",
+    "AWS::LakeFormation::Permissions": "062fc8932c9970c4",
+    "AWS::LakeFormation::PrincipalPermissions": "89fd48f71918cde3",
+    "AWS::LakeFormation::Resource": "64382446e2262067",
+    "AWS::LakeFormation::Tag": "e6965562c3f7e5bb",
+    "AWS::LakeFormation::TagAssociation": "22d7f7ee98ca2b17",
     "AWS::Lambda::Alias": "88c6e095730810db",
     "AWS::Lambda::EventInvokeConfig": "eb90a4c91675fe09",
     "AWS::Lambda::EventSourceMapping": "ab79afd9e900b271",
@@ -352,7 +370,7 @@ types: dict[str, str] = {
     "AWS::Logs::DeliveryDestination": "30b61a3515971eda",
     "AWS::Logs::DeliverySource": "67b64320b397d6cd",
     "AWS::Logs::Destination": "ff1e6b020f2cf8e7",
-    "AWS::Logs::LogGroup": "7144d581f2e97160",
+    "AWS::Logs::LogGroup": "364a0898ae2cfeb8",
     "AWS::Logs::LogStream": "bb97d1fb38ff99db",
     "AWS::Logs::MetricFilter": "9a1d875b35cd0f81",
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
@@ -405,7 +423,8 @@ types: dict[str, str] = {
     "AWS::PCAConnectorAD::ServicePrincipalName": "6a8ea7b9a179bc85",
     "AWS::PCAConnectorAD::Template": "ed0b568c05022bdf",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry": "756784fc38981208",
-    "AWS::RAM::ResourceShare": "301739e35a5f7f66",
+    "AWS::RAM::Permission": "740a6e8ada63a5a3",
+    "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
     "AWS::RDS::DBCluster": "9c7540d3d4699497",
     "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
     "AWS::RDS::DBInstance": "b7cc196bc1fe0b0d",
@@ -426,6 +445,7 @@ types: dict[str, str] = {
     "AWS::Redshift::EndpointAccess": "b9824e20c8b887c4",
     "AWS::Redshift::EndpointAuthorization": "e72be424d109da1d",
     "AWS::Redshift::EventSubscription": "53db04ab09eaba8e",
+    "AWS::Redshift::Integration": "a386ce60053e2aa9",
     "AWS::Redshift::ScheduledAction": "51bcaaee4f45725e",
     "AWS::ResourceExplorer2::DefaultViewAssociation": "a7cd7349891d3ea3",
     "AWS::ResourceExplorer2::Index": "b67cbdd9ae9d9f39",
@@ -443,13 +463,13 @@ types: dict[str, str] = {
     "AWS::Route53Resolver::FirewallRuleGroupAssociation": "d84c68a6ebbb5876",
     "AWS::Route53Resolver::ResolverConfig": "174be26547caaa42",
     "AWS::Route53Resolver::ResolverDNSSECConfig": "813fd8fe1e24c6e3",
-    "AWS::Route53Resolver::ResolverEndpoint": "8d7bd275c544d896",
+    "AWS::Route53Resolver::ResolverEndpoint": "d0ad42bf85f59279",
     "AWS::Route53Resolver::ResolverQueryLoggingConfig": "78d814f813fdbcbf",
     "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation": "41e93f940f8bce93",
     "AWS::Route53Resolver::ResolverRule": "a5bf3dc0f2b44d80",
     "AWS::Route53Resolver::ResolverRuleAssociation": "3e5cdfc8643c083b",
     "AWS::S3::AccessPoint": "e8b95810dd8d6917",
-    "AWS::S3::Bucket": "1aa877c9b86f9e89",
+    "AWS::S3::Bucket": "bc2a891a463ee5ee",
     "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
     "AWS::S3ObjectLambda::AccessPoint": "2d6b2b82a9508114",
     "AWS::S3ObjectLambda::AccessPointPolicy": "fd6328c6c782223a",
@@ -464,8 +484,8 @@ types: dict[str, str] = {
     "AWS::SSM::Association": "ad263c9023f92e0c",
     "AWS::SSM::Document": "8b3a8b629d6edee1",
     "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
-    "AWS::SSM::MaintenanceWindowTarget": "67da7a687adc34fb",
-    "AWS::SSM::MaintenanceWindowTask": "bdd479736cab2d77",
+    "AWS::SSM::MaintenanceWindowTarget": "16bcb928c1d2233d",
+    "AWS::SSM::MaintenanceWindowTask": "ce68f32e2ef0a575",
     "AWS::SSM::Parameter": "c247b226112c5ae5",
     "AWS::SSM::PatchBaseline": "43cce065b6753223",
     "AWS::SSM::ResourceDataSync": "f92ce1aa6674b7f2",
@@ -493,6 +513,13 @@ types: dict[str, str] = {
     "AWS::StepFunctions::StateMachineAlias": "55cc66ee1f33c9f5",
     "AWS::StepFunctions::StateMachineVersion": "4467293a52255b78",
     "AWS::Synthetics::Canary": "895da8ad2bfe9dad",
+    "AWS::Transfer::Agreement": "ed933cf6f3e7c136",
+    "AWS::Transfer::Certificate": "f7478973edec7bd3",
+    "AWS::Transfer::Connector": "5ff069df52b96462",
+    "AWS::Transfer::Profile": "88c7478695f7c070",
+    "AWS::Transfer::Server": "90b633961fce2a5f",
+    "AWS::Transfer::User": "7dbec614b03c1346",
+    "AWS::Transfer::Workflow": "657766d62aa7fb4e",
     "AWS::VerifiedPermissions::Policy": "f7e75c34791cf6a5",
     "AWS::VerifiedPermissions::PolicyStore": "5883732ea6547044",
     "AWS::VerifiedPermissions::PolicyTemplate": "067128efc0e8f2eb",
