@@ -40,7 +40,7 @@ types: dict[str, str] = {
     "AWS::ApiGatewayV2::Authorizer": "69107e1e01673765",
     "AWS::ApiGatewayV2::Deployment": "81174b55f308dad3",
     "AWS::ApiGatewayV2::DomainName": "87535a11b8340a18",
-    "AWS::ApiGatewayV2::Integration": "dde532823abe537b",
+    "AWS::ApiGatewayV2::Integration": "77743451e77a7545",
     "AWS::ApiGatewayV2::IntegrationResponse": "a319db9e828555fa",
     "AWS::ApiGatewayV2::Model": "fcc09a7d8ffbd09c",
     "AWS::ApiGatewayV2::Route": "112b036b7d923f13",
@@ -80,7 +80,7 @@ types: dict[str, str] = {
     "AWS::Athena::NamedQuery": "8adbac6f36c9aa6b",
     "AWS::Athena::PreparedStatement": "f136b10278378b55",
     "AWS::Athena::WorkGroup": "98125aa523006e5f",
-    "AWS::AutoScaling::AutoScalingGroup": "8fe2b009cdacf409",
+    "AWS::AutoScaling::AutoScalingGroup": "05a01deca7473008",
     "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
     "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
@@ -130,7 +130,7 @@ types: dict[str, str] = {
     "AWS::CloudFront::RealtimeLogConfig": "b264602b5a4f383b",
     "AWS::CloudFront::ResponseHeadersPolicy": "d5eaaa7cf7b104dc",
     "AWS::CloudFront::StreamingDistribution": "b9728ac9dbd5af28",
-    "AWS::CloudTrail::Trail": "49fc1232e5cd1c2b",
+    "AWS::CloudTrail::Trail": "7fca39d8e460aae0",
     "AWS::CloudWatch::Alarm": "c5552fedb35a08eb",
     "AWS::CloudWatch::AnomalyDetector": "13b8b743191bf50f",
     "AWS::CloudWatch::CompositeAlarm": "5c9a218af0588cb5",
@@ -160,7 +160,7 @@ types: dict[str, str] = {
     "AWS::Config::StoredQuery": "c02d3b47f92dac62",
     "AWS::DLM::LifecyclePolicy": "0287ea6dffbb40a2",
     "AWS::DMS::Certificate": "89efe57b4144e9ab",
-    "AWS::DMS::DataProvider": "7c7365975be25275",
+    "AWS::DMS::DataProvider": "94c68c86840900fc",
     "AWS::DMS::Endpoint": "945bb565b81d0034",
     "AWS::DMS::EventSubscription": "fdd5de7c61bc5946",
     "AWS::DMS::InstanceProfile": "b289107706553b44",
@@ -194,13 +194,13 @@ types: dict[str, str] = {
     "AWS::DocDB::DBInstance": "253562f270b587ac",
     "AWS::DocDB::DBSubnetGroup": "ccb97a9452b2284d",
     "AWS::DocDB::EventSubscription": "d22815028d03f301",
-    "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
+    "AWS::DynamoDB::GlobalTable": "bfb73ef91cc656d2",
     "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
     "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
     "AWS::EC2::CapacityReservationFleet": "3cec76abc326e6e7",
     "AWS::EC2::CustomerGateway": "5c3cdba89933c1e2",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "2667c807051620b3",
+    "AWS::EC2::EC2Fleet": "46456be2fbbfb010",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -235,7 +235,7 @@ types: dict[str, str] = {
     "AWS::EC2::SecurityGroupIngress": "367136b2f03f428c",
     "AWS::EC2::SecurityGroupVpcAssociation": "f48680388ee894fe",
     "AWS::EC2::SnapshotBlockPublicAccess": "f6434397a8c7e382",
-    "AWS::EC2::SpotFleet": "d389b8af6ecb0e0b",
+    "AWS::EC2::SpotFleet": "b3c6b5b2f4a5b7d2",
     "AWS::EC2::Subnet": "a60b8dc0c7f50396",
     "AWS::EC2::SubnetCidrBlock": "473785ce782ba18f",
     "AWS::EC2::SubnetNetworkAclAssociation": "6b4f4042734e67b7",
@@ -283,7 +283,7 @@ types: dict[str, str] = {
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
     "AWS::ECR::Repository": "d569f41026af3be8",
     "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
-    "AWS::ECS::CapacityProvider": "5804cc1956f638f2",
+    "AWS::ECS::CapacityProvider": "e838474b874da177",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
@@ -298,7 +298,7 @@ types: dict[str, str] = {
     "AWS::EKS::Cluster": "f17916cc287d09df",
     "AWS::EKS::FargateProfile": "71e821ce6e609193",
     "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
-    "AWS::EKS::Nodegroup": "287f4d78035a9e03",
+    "AWS::EKS::Nodegroup": "4b7b3ba6fffc3e8a",
     "AWS::EKS::PodIdentityAssociation": "d4249aaeb9409683",
     "AWS::EMR::Cluster": "ac0466c8197ef416",
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
@@ -352,7 +352,7 @@ types: dict[str, str] = {
     "AWS::FSx::Volume": "e2217632738abb7f",
     "AWS::GameLift::Alias": "5c014b121a693be2",
     "AWS::GameLift::Build": "b9b218f4180db0c3",
-    "AWS::GameLift::Fleet": "7b1de719fe632688",
+    "AWS::GameLift::Fleet": "08322d2081d018bb",
     "AWS::GameLift::GameServerGroup": "5cc95b605dfa9939",
     "AWS::GameLift::GameSessionQueue": "aba577170457cc78",
     "AWS::GameLift::MatchmakingConfiguration": "d94ba396d6b23182",
@@ -456,7 +456,7 @@ types: dict[str, str] = {
     "AWS::IoT::ThingGroup": "7fa472878da23f08",
     "AWS::IoT::ThingPrincipalAttachment": "cb2db377e7001773",
     "AWS::IoT::ThingType": "472326c990487efa",
-    "AWS::IoT::TopicRule": "b031e429916b85bb",
+    "AWS::IoT::TopicRule": "4fcf915e11a87a98",
     "AWS::IoT::TopicRuleDestination": "1113af4de44b3cb0",
     "AWS::IoTAnalytics::Channel": "4b80a172cab89c05",
     "AWS::IoTAnalytics::Dataset": "d85b607a0e28e682",
@@ -480,7 +480,7 @@ types: dict[str, str] = {
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
     "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
-    "AWS::KafkaConnect::Connector": "08b81c973eb812dd",
+    "AWS::KafkaConnect::Connector": "9ca5dec677704b80",
     "AWS::KafkaConnect::CustomPlugin": "f04fc57818e8ddb4",
     "AWS::KafkaConnect::WorkerConfiguration": "8a9b885926e8a00c",
     "AWS::Kinesis::ResourcePolicy": "39996915810e234a",
@@ -516,7 +516,7 @@ types: dict[str, str] = {
     "AWS::Logs::DeliveryDestination": "30b61a3515971eda",
     "AWS::Logs::DeliverySource": "67b64320b397d6cd",
     "AWS::Logs::Destination": "ff1e6b020f2cf8e7",
-    "AWS::Logs::LogGroup": "7144d581f2e97160",
+    "AWS::Logs::LogGroup": "364a0898ae2cfeb8",
     "AWS::Logs::LogStream": "bb97d1fb38ff99db",
     "AWS::Logs::MetricFilter": "9a1d875b35cd0f81",
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
@@ -567,10 +567,10 @@ types: dict[str, str] = {
     "AWS::Personalize::Solution": "bf8a32c997c789a9",
     "AWS::Pipes::Pipe": "052457cd8332df71",
     "AWS::QuickSight::Analysis": "9ed141915b114fbd",
-    "AWS::QuickSight::CustomPermissions": "ac2895cdbe3ee0f3",
+    "AWS::QuickSight::CustomPermissions": "da6da182c0c23fb4",
     "AWS::QuickSight::Dashboard": "b1b7368590994f86",
     "AWS::QuickSight::DataSet": "0e9e94a2fd9e8f95",
-    "AWS::QuickSight::DataSource": "2c06940063cc0519",
+    "AWS::QuickSight::DataSource": "407708b753626383",
     "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
     "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
     "AWS::QuickSight::Template": "9f99a52291094b16",
@@ -580,11 +580,11 @@ types: dict[str, str] = {
     "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
     "AWS::RDS::DBCluster": "9c7540d3d4699497",
     "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
-    "AWS::RDS::DBInstance": "b7cc196bc1fe0b0d",
+    "AWS::RDS::DBInstance": "25726c9e8467f4c5",
     "AWS::RDS::DBParameterGroup": "d29cf38b861f6048",
-    "AWS::RDS::DBProxy": "6a3bd3de0c3a9c96",
-    "AWS::RDS::DBProxyEndpoint": "db0fcba23f51c12d",
-    "AWS::RDS::DBProxyTargetGroup": "8ee69ccb4de53286",
+    "AWS::RDS::DBProxy": "308e70305b33a892",
+    "AWS::RDS::DBProxyEndpoint": "17943cc672d084c2",
+    "AWS::RDS::DBProxyTargetGroup": "b584b6fb42fcd4c7",
     "AWS::RDS::DBSecurityGroup": "42f555e782cd9946",
     "AWS::RDS::DBSecurityGroupIngress": "1a14ad6e73c0b6b7",
     "AWS::RDS::DBShardGroup": "df6b36c7e099595a",
@@ -633,7 +633,7 @@ types: dict[str, str] = {
     "AWS::S3::AccessGrantsInstance": "05d3e874b43bbad8",
     "AWS::S3::AccessGrantsLocation": "3a7be1727f630029",
     "AWS::S3::AccessPoint": "e8b95810dd8d6917",
-    "AWS::S3::Bucket": "bc2a891a463ee5ee",
+    "AWS::S3::Bucket": "f2e96ae4922bbb57",
     "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
     "AWS::S3::StorageLens": "e20ccca5b946adc3",
     "AWS::S3::StorageLensGroup": "a48c03e67d334c14",
@@ -642,6 +642,11 @@ types: dict[str, str] = {
     "AWS::S3Express::DirectoryBucket": "06fdc76e1b66a21f",
     "AWS::S3ObjectLambda::AccessPoint": "2d6b2b82a9508114",
     "AWS::S3ObjectLambda::AccessPointPolicy": "fd6328c6c782223a",
+    "AWS::S3Tables::Namespace": "44b5d6ca79e89650",
+    "AWS::S3Tables::Table": "9fef59bdfa5bd960",
+    "AWS::S3Tables::TableBucket": "f26569515da002c0",
+    "AWS::S3Tables::TableBucketPolicy": "b3ab0f647d7aed60",
+    "AWS::S3Tables::TablePolicy": "0ed301e1967bd6a0",
     "AWS::SDB::Domain": "48c38397df169b43",
     "AWS::SNS::Subscription": "9426c559a25e9da6",
     "AWS::SNS::Topic": "dfcf55503343941a",
@@ -683,7 +688,7 @@ types: dict[str, str] = {
     "AWS::SageMaker::ProcessingJob": "9bf6e74e7f3d53e1",
     "AWS::SageMaker::Project": "c10c82bc5a09a5dc",
     "AWS::SageMaker::StudioLifecycleConfig": "5b453bb7816eb95b",
-    "AWS::SageMaker::UserProfile": "d2a4b7455b2cbd74",
+    "AWS::SageMaker::UserProfile": "6300c02533605472",
     "AWS::SageMaker::Workteam": "d617e40122a8fe93",
     "AWS::Scheduler::Schedule": "e8b60514af25a837",
     "AWS::Scheduler::ScheduleGroup": "ef710d09dbb243bf",
